@@ -65,7 +65,7 @@ def requiredObjectClassesProperty(**kwargs):
 	pargs = dict(
 		short_description=_('Required object class'),
 		long_description='',
-		syntax=univention.admin.syntax.string,
+		syntax=univention.admin.syntax.ldapObjectClass,
 		multivalue=True,
 	)
 	pargs.update(kwargs)
@@ -77,7 +77,7 @@ def prohibitedObjectClassesProperty(**kwargs):
 	pargs = dict(
 		short_description=_('Excluded object class'),
 		long_description='',
-		syntax=univention.admin.syntax.string,
+		syntax=univention.admin.syntax.ldapObjectClass,
 		multivalue=True,
 	)
 	pargs.update(kwargs)
