@@ -48,9 +48,6 @@ import univention.admin.handlers.users.user
 import univention.admin.handlers.groups.group
 import univention.admin.handlers.computers.windows
 
-# update choices-lists which are defined in LDAP
-univention.admin.syntax.update_choices()
-
 
 def status(msg):
 	# univention-adduser is called by Samba when doing "vampire." Since
